trove_classifiers: Canonical source for classifiers on PyPI (pypi.org)
======================================================================

Description
-----------

Canonical source for classifiers on PyPI (pypi.org)

License
-------

Upstream Contact
----------------

https://pypi.org/project/trove-classifiers/

